@@ -767,7 +767,7 @@ void MPVProcess::displayInfoOnOSD() {
 		//tab + b1 + tr("Display FPS:") + b0 + " ${display-fps}" + nl +
 		tab + b1 + tr("Aspect Ratio:") + b0 + " ${video-params/aspect}" + nl +
 		tab + b1 + tr("Bitrate:") + b0 + " ${video-bitrate}" + nl +
-		tab + b1 + tr("Dropped frames:") + b0 + " ${drop-frame-count}" + nl +
+		tab + b1 + tr("Dropped frames:") + b0 + " ${decoder-frame-drop-count:${drop-frame-count}}" + nl +
 		nl +
 
 		b1 + tr("Audio:") + b0 + " ${audio-codec}" + nl + 
@@ -1079,12 +1079,24 @@ void MPVProcess::changeStereo3DFilter(bool enable, const QString & in, const QSt
 	writeToStdin(QString("vf %1 \"%2\"").arg(enable ? "add" : "del").arg(filter));
 }
 
-void MPVProcess::setSubStyles(const AssStyles & styles, const QString &) {
-	QString sub_font = "--sub-text-font";
-	if (isOptionAvailable("--sub-font")) sub_font = "--sub-font";
+#if 0
 
-	QString sub_color = "--sub-text-color";
-	if (isOptionAvailable("--sub-color")) sub_color = "--sub-color";
+#define SUBOPTION(name, alternative1, alternative2) \
+	QString name = alternative2;
+
+#else
+
+#define SUBOPTION(name, alternative1, alternative2) \
+	QString name; \
+	if (isOptionAvailable(alternative1)) name = alternative1; \
+	else \
+	if (isOptionAvailable(alternative2)) name = alternative2;
+
+#endif
+
+void MPVProcess::setSubStyles(const AssStyles & styles, const QString &) {
+	SUBOPTION(sub_font, "--sub-font", "--sub-text-font");
+	SUBOPTION(sub_color, "--sub-color", "--sub-text-color");
 
 	QString sub_shadow_color = "--sub-text-shadow-color";
 	if (isOptionAvailable("--sub-shadow-color")) sub_shadow_color = "--sub-shadow-color";
@@ -1092,40 +1104,54 @@ void MPVProcess::setSubStyles(const AssStyles & styles, const QString &) {
 	QString sub_back_color = "--sub-text-back-color";
 	if (isOptionAvailable("--sub-back-color")) sub_back_color = "--sub-back-color";
 
-	QString sub_border_color = "--sub-text-border-color";
-	if (isOptionAvailable("--sub-border-color")) sub_border_color = "--sub-border-color";
+	SUBOPTION(sub_border_color, "--sub-border-color", "--sub-text-border-color");
+	SUBOPTION(sub_border_size, "--sub-border-size", "--sub-text-border-size");
+	SUBOPTION(sub_shadow_offset, "--sub-shadow-offset", "--sub-text-shadow-offset");
 
-	QString sub_border_size = "--sub-text-border-size";
-	if (isOptionAvailable("--sub-border-size")) sub_border_size = "--sub-border-size";
+	SUBOPTION(sub_font_size, "--sub-font-size", "--sub-text-font-size");
+	SUBOPTION(sub_bold, "--sub-bold", "--sub-text-bold");
+	SUBOPTION(sub_italic, "--sub-italic", "--sub-text-italic");
+	SUBOPTION(sub_align_x, "--sub-align-x", "--sub-text-align-x");
+	SUBOPTION(sub_align_y, "--sub-align-y", "--sub-text-align-y");
 
-	QString sub_shadow_offset = "--sub-text-shadow-offset";
-	if (isOptionAvailable("--sub-shadow-offset")) sub_shadow_offset = "--sub-shadow-offset";
+	if (!sub_font.isEmpty()) {
+		QString font = styles.fontname;
+		//arg << "--sub-text-font=" + font.replace(" ", "");
+		arg << sub_font + "=" + font;
+	}
 
-	QString font = styles.fontname;
-	//arg << "--sub-text-font=" + font.replace(" ", "");
-	arg << sub_font + "=" + font;
-	arg << sub_color + "=#" + ColorUtils::colorToAARRGGBB(styles.primarycolor);
+	if (!sub_color.isEmpty()) {
+		arg << sub_color + "=#" + ColorUtils::colorToAARRGGBB(styles.primarycolor);
+	}
 
 	if (styles.borderstyle == AssStyles::Outline) {
 		arg << sub_shadow_color + "=#" + ColorUtils::colorToAARRGGBB(styles.backcolor);
 	} else {
 		arg << sub_back_color + "=#" + ColorUtils::colorToAARRGGBB(styles.outlinecolor);
 	}
-	arg << sub_border_color + "=#" + ColorUtils::colorToAARRGGBB(styles.outlinecolor);
 
-	arg << sub_border_size + "=" + QString::number(styles.outline * 2.5);
-	arg << sub_shadow_offset + "=" + QString::number(styles.shadow * 2.5);
-
-	if (isOptionAvailable("--sub-text-font-size")) {
-		arg << "--sub-text-font-size=" + QString::number(styles.fontsize * 2.5);
+	if (!sub_border_color.isEmpty()) {
+		arg << sub_border_color + "=#" + ColorUtils::colorToAARRGGBB(styles.outlinecolor);
 	}
 
-	if (isOptionAvailable("--sub-text-bold")) {
-		arg << QString("--sub-text-bold=%1").arg(styles.bold ? "yes" : "no");
+	if (!sub_border_size.isEmpty()) {
+		arg << sub_border_size + "=" + QString::number(styles.outline * 2.5);
 	}
 
-	if (isOptionAvailable("--sub-text-italic")) {
-		arg << QString("--sub-text-italic=%1").arg(styles.italic ? "yes" : "no");
+	if (!sub_shadow_offset.isEmpty()) {
+		arg << sub_shadow_offset + "=" + QString::number(styles.shadow * 2.5);
+	}
+
+	if (!sub_font_size.isEmpty()) {
+		arg << sub_font_size + "=" + QString::number(styles.fontsize * 2.5);
+	}
+
+	if (!sub_bold.isEmpty()) {
+		arg << QString("%1=%2").arg(sub_bold).arg(styles.bold ? "yes" : "no");
+	}
+
+	if (!sub_italic.isEmpty()) {
+		arg << QString("%1=%2").arg(sub_italic).arg(styles.italic ? "yes" : "no");
 	}
 
 	QString halign;
@@ -1140,11 +1166,12 @@ void MPVProcess::setSubStyles(const AssStyles & styles, const QString &) {
 		case AssStyles::Top: valign = "top"; break;
 	}
 
-	if (!halign.isEmpty() || !valign.isEmpty()) {
-		if (isOptionAvailable("--sub-text-align-x")) {
-			if (!halign.isEmpty()) arg << "--sub-text-align-x=" + halign;
-			if (!valign.isEmpty()) arg << "--sub-text-align-y=" + valign;
-		}
+	if (!sub_align_x.isEmpty() && !halign.isEmpty()) {
+		arg << sub_align_x + "=" + halign;
+	}
+	
+	if (!sub_align_y.isEmpty() && !valign.isEmpty()) {
+		arg << sub_align_y + "=" + valign;
 	}
 }
 
